# openmamba kernel specfile
#
# To build a specific target:
# rpmbuild -ba --define="KERNEL_TARGET <target>" kernel.spec
#
# To cross-compile:
# rpmbuild -ba --target x86_64 --define="KERNEL_TARGET <target>" kernel.spec

#% define kernel_longterm 1
%define kernel_MAJver %(echo %version | cut -d. -f1)
%define kernel_majver %(echo %version | cut -d. -f1-2)
%define kernel_ver %(echo %version | cut -d. -f1-3)
%if "%{?kernel_longterm}" != "1"
%define kernel_pl  %(echo %version | cut -d. -f3)
%endif
%define        USE_DISTCC 0

%if "%{USE_DISTCC}" == "1"
   %define        DISTCC CC="ccache distcc" -j 12
%endif

# Build a mamba kernel if no target was specified
%if "%{?KERNEL_TARGET}" == ""
%ifarch x86_64
   %define     KERNEL_TARGET mamba-x86_64
%endif
%ifarch %{ix86}
   %define     KERNEL_TARGET mamba
%endif
%ifarch arm
   %define     KERNEL_TARGET mamba-arm
%endif
%ifarch aarch64
   %define     KERNEL_TARGET mamba-aarch64
%endif
%endif

%ifarch x86_64
   %define     localver_append -x86_64
%endif
%ifarch %{ix86}
%if "%{?KERNEL_TARGET}" != "mamba"
   %define     localver_append -64GB
%endif
%endif
%ifarch arm
   %define     localver_append -arm
%endif
%ifarch aarch64
   %define     localver_append -aarch64
%endif

# define short kernel target name for Lilo
%define     KERNEL_TARGET_SHORT %{KERNEL_TARGET}

%define     KERNEL_LOCALVER -%{release}%{?localver_append}

%define     target_cpu %{_target_cpu}
%define     DEPMOD /sbin/depmod

%define     KIMAGE_DEST vmlinuz
%if "%{_target_cpu}" == "i586"
   %define     KIMAGE arch/i386/boot/bzImage
   %define     target_cpu i386
%endif

%if "%{_target_cpu}" == "arm"
   %if "%{KERNEL_TARGET}" == "mamba-arm-dove"
      %define     KIMAGE arch/arm/boot/uImage
      %define     KIMAGE_DEST uImage
   %else
      %define     KIMAGE arch/arm/boot/zImage
   %endif
%endif

%if "%{_target_cpu}" == "x86_64"
   %if "%{KERNEL_TARGET}" == "mamba-xen"
   %define     KIMAGE arch/x86_64/boot/vmlinuz
   %else
   %define     KIMAGE arch/x86_64/boot/bzImage
   %endif
%endif

%if "%{_target_cpu}" == "aarch64"
   %define     KIMAGE arch/arm64/boot/vmlinuz
   %define     target_cpu arm64
%endif

%if "%{_target_cpu}" == "ppc"
   %define     KIMAGE vmlinux
   %define     target_cpu powerpc
%endif

# disable internal dependency generator for scriptlets
%define _use_internal_dependency_generator 1

Name:          kernel
Version:       6.6.10
Release:       1mamba
Summary:       The Linux Kernel, the operating system core itself
Group:         System/Kernel and Hardware
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
Source0:       https://cdn.kernel.org/pub/linux/kernel/v%{kernel_MAJver}.x/linux-%{kernel_ver}.tar.xz
Source11:      %{name}-%{kernel_majver}-mamba-config
Source12:      %{name}-%{kernel_majver}-mamba-x86_64-config
Source13:      %{name}-%{kernel_majver}-mamba-64GB-config
Source15:      %{name}-%{kernel_majver}-mamba-arm-config
Source21:      %{name}-%{kernel_majver}-mamba-aarch64-config
Patch11:       kernel-3.2.1-8139cp.patch
Patch24:       kernel-2.6.35-usbstorage-disable_delay_use.patch
Patch39:       kernel-3.2.1-rtl8139too.patch
Patch59:       %{name}-2.6.35-vga_dont_ask.patch
URL:           https://www.kernel.org/
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libelf-devel
BuildRequires: libopenssl-devel
BuildRequires: libperl
BuildRequires: perl-Encode
BuildRequires: perl-devel
## AUTOBUILDREQ-END
%if "%{USE_DISTCC}" == "1"
BuildRequires: distcc ccache
%endif
BuildRequires: bison >= 3.4.1

%description
The Linux Kernel, the operating system core itself.
The kernel package contains the Linux kernel (%{KIMAGE_DEST}), the operating system core itself.
The kernel handles the basic functions of the operating system: memory allocation, process allocation, device input and output, etc.
This is the source package used to build kernel for different architectures and targets.

%if "%{?KERNEL_TARGET}" != ""
%package %{KERNEL_TARGET}
Group:         System/Kernel and Hardware
Summary:       The Linux kernel, the operating system core itself
%endif
Requires(post):dracut
Requires(post):module-init-tools >= 3.1
%if "%{_target_cpu}" != "arm"
Requires(pre): bootloader
%endif
# Wireless
Provides:      kernelwireless = %{version}
Provides:      kernelwireless-%{KERNEL_TARGET}-%{kernel_ver}
Provides:      kernel-%{KERNEL_TARGET}-wireless = %{?epoch:%epoch:}%{version}-%{release}
Requires:      iwlwifi-firmware
Requires:      crda
# Sound
Provides:      kernelsound = %{version}
Provides:      kernelsound-%{KERNEL_TARGET}-%{kernel_ver}
Provides:      kernel-%{KERNEL_TARGET}-sound = %{?epoch:%epoch:}%{version}-%{release}
# Firmware
Requires:      linux-firmware
Requires:      alsa-firmware
Requires:      alsa-sof-firmware
Provides:      kernel = %{version}

%description %{KERNEL_TARGET}
The Linux Kernel, the operating system core itself.
The kernel package contains the Linux kernel (%{KIMAGE_DEST}), the operating system core itself.
The kernel handles the basic functions of the operating system: memory allocation, process allocation, device input and output, etc.
This kernel was build for %{_target_cpu} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-headers
Group:         Development/Kernel
Summary:       Headers, scripts, configuration and Makefile for the linux kernel
#Requires:      kernel-%{KERNEL_TARGET} = %{version}-%{release}
Requires(post): dkms >= 2.8.3-2mamba
Provides:      kernelheaders = %{version}

%description %{KERNEL_TARGET}-headers
The kernel-headers package contains the headers, scripts, configuration and Makefile to develop with the linux kernel
The kernel-headers can be used to build modules for the kernel.
This kernel headers are configured for %{TARGET_CPU} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-headers-sanitised
Group:         Development/Kernel
Summary:       Sanitised kernel headers used for glibc build
Provides:      kernelsanitisedheaders = %{version}

%description %{KERNEL_TARGET}-headers-sanitised
Sanitised kernel headers used for glibc build.
This kernel sanitised headers are configured for %{TARGET_CPU} architecture and the following target: %{?KERNEL_TARGET}.

# Don't clean build at the end
%global __spec_rmbuild_cmd /bin/true

%prep
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"

ld -v | grep "gold" && {
   echo "Error: ld GOLD detected, which is incompatible with this package. Aborting."
   exit 1
}

%if "%{?KERNEL_TARGET}" == ""
   echo "No target specified, aborting."
   exit 1
%else
   echo "I'm going to build a %{KERNEL_TARGET} kernel..."
%endif

%setup -q -c -n %{name}-%{kernel_ver}%{?KERNEL_TARGET}
#-D -T
#:<< ___EOF
%if "%{?kernel_longterm}" == ""
mv linux-%{kernel_ver}/* .
rm -r linux-%{kernel_ver}
%else
mv linux-%{version}/* .
rm -r linux-%{version}
%endif

# Disable build-ids to avoid conflicts
%define _build_id_links none

# add here subrelease patch
#%if "%{?kernel_longterm}" != "1"
#%if "%{?kernel_pl}" != ""
#echo "%{?kernel_pl}"
#xzcat -c %{SOURCE1} >/dev/null || exit 1
#xzcat -c %{SOURCE1} | patch -p1
#%endif
#%endif
#sed -i "s/\(SUBLEVEL =\).*/\1/" Makefile

#
# patch and configure STANDARD kernel
#

make mrproper

# usbstorage disable delay_use patch (disabled since kernel 2.6.35 because patched from 5 to 1 sec instead of 5 to 0)
%patch 24 -p1
# rtl_8139too patch
%patch 39 -p1
%patch 59 -p1

# Setting version
#scripts/setlocalversion --save-scmversion
#___EOF

# create build dirs for each kernel
# and copy proper configuration
%if "%{_target_cpu}" == "i586"
   case %{?KERNEL_TARGET} in
      mamba) kernel_cfg=%{SOURCE11}
               ;;
      mamba-64GB) kernel_cfg=%{SOURCE13}
               ;;
   esac
%endif
%if "%{_target_cpu}" == "x86_64"
   case %{?KERNEL_TARGET} in
      mamba-x86_64) kernel_cfg=%{SOURCE12}
               ;;
   esac
%endif
%if "%{_target_cpu}" == "arm"
   case %{?KERNEL_TARGET} in
      mamba-arm) kernel_cfg=%{SOURCE15} ;;
      mamba-arm-kirkwood) kernel_cfg=%{SOURCE18} ;;
      mamba-arm-dove) kernel_cfg=%{SOURCE20} ;;
   esac
%endif
%if "%{_target_cpu}" == "aarch64"
   case %{?KERNEL_TARGET} in
      mamba-aarch64) kernel_cfg=%{SOURCE21} ;;
   esac
%endif
cp $kernel_cfg ./.config

#___EOF
echo "%{KERNEL_LOCALVER}" > localversion.20-pkgname

%build
#
# build kernel for given target
#
#:<< __EOF
sed -i 's@/usr/bin/env@/bin/env@' ./arch/ia64/scripts/unwcheck.py
ARCH=%{target_cpu} make oldconfig

make -s kernelrelease > version

PATH=%{_bindir}:$PATH \
ARCH=%{target_cpu} \
	make CROSS_COMPILE=%{_target_platform}- \
	%{?_smp_mflags} \
	%{?DISTCC} \
	all %{?KIMAGE_TARGET}

if [ "%{?KERNEL_TARGET}" = "mamba-arm-dove" ]; then
   # See www.solid-run.com/mw/index.php?title=Device_Tree
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
   cp arch/arm/boot/zImage arch/arm/boot/zImage.orig
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} dove-cubox.dtb
   cat arch/arm/boot/zImage.orig arch/arm/boot/dts/dove-cubox.dtb > arch/arm/boot/zImage
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
fi

#%if %{_target_cpu} == arm
#ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
#%endif

%install
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"

# create system dirs in install environment
install -d %{buildroot}{/usr/src/,/boot,/lib/modules}

#
# install modules
#
ARCH=%{target_cpu} make \
   modules_install INSTALL_MOD_PATH=%{buildroot} INSTALL_MOD_STRIP=1

install -m0644 modules.builtin %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/
install -m0644 modules.order %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/

(cd %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}
rm -f build && ln -sf /usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER} build )

# clean modules files created by depmod
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.{alias,alias.bin,ccwmap,dep,dep.bin,devname,ieee1394map}
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.{inputmap,isapnpmap,ofmap,pcimap,seriomap,softdep}
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.{symbols,symbols.bin,usbmap}

#
# install boot files
#
cp %{KIMAGE} %{buildroot}/boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_LOCALVER}
# install dts files
%ifarch aarch64
cp -a arch/%{target_cpu}/boot/dts %{buildroot}/boot/
%endif

#%if %{_target_cpu} == arm
#cp arch/arm/boot/uImage %{buildroot}/boot/uImage-%{kernel_ver}%{?KERNEL_LOCALVER}
#%endif

cp System.map %{buildroot}/boot/System.map-%{kernel_ver}%{?KERNEL_LOCALVER}

#
# install sanitised headers used by glibc
#
ARCH=%{target_cpu} make headers_install \
   HOSTCC=%{_build}-gcc \
   CROSS_COMPILE=%{_target_platform}- \
   INSTALL_HDR_PATH=%{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{KERNEL_LOCALVER}/usr
   
#
# install kernel headers
#

case %{_target_cpu} in
   i586|x86_64) headers_arch="x86" ;;
   arm) headers_arch="arm" ;;
   aarch64) headers_arch="arm64" ;;
   ppc) headers_arch="powerpc" ;;
esac

build_dir=%{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{KERNEL_LOCALVER}

install -Dt ${build_dir} -m644 .config Makefile Module.symvers System.map localversion.* version
install -Dt ${build_dir}/kernel -m644 kernel/Makefile
install -Dt ${build_dir}/arch/${headers_arch} -m644 arch/${headers_arch}/Makefile* arch/${headers_arch}/Kbuild
cp -t ${build_dir} -a scripts

# add objtool for external module building and enabled VALIDATION_STACK option
[ -e tools/objtool/objtool ] && install -Dt ${build_dir}/tools/objtool tools/objtool/objtool

# add xfs and shmem for aufs building
mkdir -p ${build_dir}/{fs/xfs,mm}

# installing headers
cp -t ${build_dir} -a include
install -d ${build_dir}/tools
cp -t ${build_dir}/tools -a tools/include

# Needed build files
#cp -t ${build_dir}/arch/${headers_arch} -a arch/${headers_arch}/entry
cp -t ${build_dir}/arch/${headers_arch} -a arch/${headers_arch}/include

install -Dt ${build_dir}/arch/${headers_arch}/kernel -m644 arch/${headers_arch}/kernel/asm-offsets.s
%ifnarch aarch64
cp -r arch/${headers_arch}/tools ${build_dir}/arch/${headers_arch}
%endif

# install Kconfig files
find . -name 'Kconfig*' -exec install -Dm644 {} ${build_dir}/{} \;

# Remove unneeded architectures
for arch in ${build_dir}/arch/*/; do
    [[ $arch = */${headers_arch}/ ]] && continue
    echo "Removing $(basename "$arch")"
    rm -r "$arch"
done

# Remove broken symlinks
find -L ${build_dir} -type l -printf 'Removing %%P\n' -delete

# Remove loose objects
find ${build_dir} -type f -name '*.o' -printf 'Removing %%P\n' -delete

# Stripping vmlinux
#strip -v ${build_dir}/vmlinux

# Remove sources link
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/source

## Remove Kconfig in Documentation
#rm -r ${build_dir}/Documentation

# Do not package cross-platform host tools
if [ "%{_build}" != "%{_target_platform}" ]; then
   for f in asn1_compiler conmakehash extract-cert kallsyms sortextable; do
      rm -f %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/scripts/$f
   done
fi

%clean
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%postun %{?KERNEL_TARGET}
# erase this package
if [ $1 -eq 0 ]; then
   [ -f /boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_LOCALVER} ] ||
      rm -f /boot/initramfs-%{kernel_ver}%{?KERNEL_LOCALVER}.img
fi
:

%posttrans %{?KERNEL_TARGET}
# clean our orphan old initramfs
ls /boot/initramfs-*-failsafe.img | \
while read line; do
   k=${line/\/boot\/initramfs-}
   k=${k/-failsafe.img}
   [ -e /boot/vmlinuz-$k ] || \
       rm -f /boot/initramfs-$k.img /boot/initramfs-$k-failsafe.img
done
# clean old and empty /usr/src/linux-* directories
for f in /usr/src/linux-*; do
 if [ ! -L $f ]; then
  a=`find $f -type f -a -not -name MARKER -print -quit | wc -l`
  if [ $a -eq 0 -a "$f" != "/" ]; then
   rm -rf $f
  fi
 fi
done

# new install or upgrade
/sbin/depmod -a -F /boot/System.map-%{kernel_ver}%{?KERNEL_LOCALVER} \
   %{kernel_ver}%{?KERNEL_LOCALVER} &>/dev/null

# create local system initramfs
/usr/sbin/mkinitrd -H -f /boot/initramfs-%{kernel_ver}%{?KERNEL_LOCALVER}.img %{kernel_ver}%{?KERNEL_LOCALVER}

# create system-wide "failsafe" initramfs
/usr/sbin/dracut -f --filesystems "ext3 squashfs isofs reiserfs ext4" \
       --nomdadmconf --nolvmconf -k /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER} \
       /boot/initramfs-%{kernel_ver}%{?KERNEL_LOCALVER}-failsafe.img %{kernel_ver}%{?KERNEL_LOCALVER}

# all done, now ring grub-update
%if "%{_target_cpu}" == "i586"
  if [ -x /usr/sbin/grub-update ]; then
     /usr/sbin/grub-update
  fi
  if [ -x /usr/sbin/update-grub ]; then
     /usr/sbin/update-grub 2>/dev/null
     grub-set-default 0
  fi
%endif
%if "%{_target_cpu}" == "x86_64"
  if [ -x /usr/sbin/grub-update ]; then
     /usr/sbin/grub-update
  fi
  if [ -x /usr/sbin/update-grub ]; then
     /usr/sbin/update-grub 2>/dev/null
     grub-set-default 0
  fi
%endif
:

%post %{KERNEL_TARGET}-headers
# touch file so it results up-to-date on make
if [ $1 -ge 1 ]; then
   touch %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/include/config/MARKER
   [ -x /usr/sbin/dkms ] && dkms autoinstall -q --kernelver %{kernel_ver}%{?KERNEL_LOCALVER} || true
   ln -snf %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER} %{_prefix}/src/linux-mamba%{?localver_append}
fi
:

%post %{KERNEL_TARGET}-headers-sanitised
if [ $1 -ge 1 ]; then
   ln -snf %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER} %{_prefix}/src/linux-mamba%{?localver_append}
fi
:

%files %{?KERNEL_TARGET}
%defattr (-, root, root)
/boot/System.map-%{kernel_ver}%{?KERNEL_LOCALVER}
/boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_LOCALVER}
%ifarch aarch64
%dir /boot/dts
/boot/dts/*
%endif
#%if %{_target_cpu} == arm
#/boot/uImage-%{kernel_ver}%{?KERNEL_LOCALVER}
#%endif
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.builtin
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.builtin.alias.bin
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.builtin.bin
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.builtin.modinfo
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/modules.order
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/arch
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/block
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/block/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/crypto
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/crypto/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/drivers
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/drivers/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/fs
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/fs/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/locking
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/locking/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/rcu
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/rcu/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/time
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/kernel/time/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/lib
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/lib/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/mm
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/mm/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/net
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/net/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/security
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/security/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/sound
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/sound/*
%ifnarch aarch64
%dir /lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/virt
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/kernel/virt/*
%endif
%doc COPYING CREDITS MAINTAINERS

%files %{KERNEL_TARGET}-headers-sanitised
%defattr(-,root,root)
%dir /usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/usr/include

%files %{KERNEL_TARGET}-headers
%defattr(-,root,root)
%dir /usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/localversion.20-pkgname
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/Documentation
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/Makefile
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/Module.symvers
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/System.map
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/.config
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/scripts
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/version
#/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/vmlinux
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/Kconfig
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/arch
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/block
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/certs
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/crypto
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/drivers
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/fs
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/kernel
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/include
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/init
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/lib
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/mm
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/net
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/samples
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/security
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/sound
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/tools
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/virt
/usr/src/linux-%{kernel_ver}%{?KERNEL_LOCALVER}/usr
/lib/modules/%{kernel_ver}%{?KERNEL_LOCALVER}/build

%changelog
* Fri Jan 05 2024 Automatic Build System <autodist@openmamba.org> 6.6.10-1mamba
- automatic version update by autodist

* Mon Jan 01 2024 Automatic Build System <autodist@mambasoft.it> 6.6.9-1mamba
- automatic version update by autodist

* Sun Dec 24 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.6.8-1mamba
- update to 6.6.8

* Mon Nov 27 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.63-1mamba
- update to 6.1.63

* Tue Oct 10 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.56-1mamba
- update to 6.1.56

* Thu Aug 03 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.43-1mamba
- update to 6.1.43

* Tue May 30 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.31-1mamba
- update to 6.1.31

* Wed Apr 19 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.24-1mamba
- update to 6.1.24
- fix typo in initramfs creation command

* Wed Apr 12 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.23-1mamba
- update to 6.1.23

* Sun Mar 26 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.21-1mamba
- update to 6.1.21
- unset CONFIG_RT_GROUP_SCHED=n to fix rtkit (remembering to check that docker does not complain)

* Fri Mar 10 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.16-1mamba
- update to 6.1.16

* Wed Feb 15 2023 Automatic Build System <autodist@mambasoft.it> 6.1.12-1mamba
- automatic version update by autodist

* Sun Feb 12 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.11-1mamba
- update to 6.1.11

* Sat Feb 11 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.93-1mamba
- update to 5.15.93

* Sat Dec 24 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.85-1mamba
- update to 5.15.85
- headers: fix x86 external modules build by installing arch/x86/Makefile_32.cpu (and other build files from this dir)

* Sat Oct 22 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.74-1mamba
- update to 5.15.74

* Sat Oct 01 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.71-1mamba
- update to 5.15.71
- enable KPROBES for anbox

* Sat Sep 17 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.68-1mamba
- update to 5.15.68

* Mon Jul 25 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.57-1mamba
- update to 5.15.57

* Fri Jun 03 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.44-1mamba
- update to 5.15.44
- set CONFIG_PSI=y required by systemd-oomd, CONFIG_RESET_ATTACK_MITIGATION=y, CONFIG_BPF_UNPRIV_DEFAULT_OFF=y

* Thu Mar 31 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.32-1mamba
- update to 5.15.32

* Sun Jan 30 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.15.18-1mamba
- update to 5.15.18

* Sat Jan 29 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.95-1mamba
- update to 5.10.95

* Tue Nov 23 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.81-1mamba
- update to 5.10.81

* Thu Sep 09 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.63-1mamba
- update to 5.10.63

* Mon Aug 09 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.57-1mamba
- update to 5.10.57

* Sun Aug 08 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.56-2mamba
- fix for appended local version

* Sat Aug 07 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.56-1mamba
- update to 5.10.56

* Thu Jun 24 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.46-1mamba
- update to 5.10.46

* Sun May 09 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.35-1mamba
- update to 5.10.35
- config: enabled CONFIG_TASK_XACCT and CONFIG_TASK_IO_ACCOUNTING for iotop

* Sat May 01 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.33-3mamba
- add release to local version to fix release updates

* Fri Apr 30 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.33-2mamba
- (re)enable NVS 4.1 and 4.2

* Thu Apr 29 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.33-1mamba
- update to 5.10.33

* Thu Mar 04 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 5.10.19-1mamba
- update to 5.10.19

* Wed Oct 07 2020 Automatic Build System <autodist@mambasoft.it> 5.8.14-1mamba
- automatic version update by autodist

* Fri Oct 02 2020 Automatic Build System <autodist@mambasoft.it> 5.8.13-1mamba
- automatic version update by autodist

* Sat Sep 26 2020 Automatic Build System <autodist@mambasoft.it> 5.8.12-1mamba
- automatic version update by autodist

* Wed Sep 23 2020 Automatic Build System <autodist@mambasoft.it> 5.8.11-1mamba
- automatic version update by autodist

* Thu Sep 17 2020 Automatic Build System <autodist@mambasoft.it> 5.8.10-1mamba
- automatic version update by autodist

* Sat Sep 12 2020 Automatic Build System <autodist@mambasoft.it> 5.8.9-1mamba
- automatic version update by autodist

* Thu Sep 10 2020 Automatic Build System <autodist@mambasoft.it> 5.8.8-1mamba
- automatic version update by autodist

* Sun Sep 06 2020 Automatic Build System <autodist@mambasoft.it> 5.8.7-1mamba
- automatic version update by autodist

* Sat Aug 01 2020 Automatic Build System <autodist@mambasoft.it> 5.7.12-1mamba
- automatic version update by autodist

* Thu Jul 30 2020 Automatic Build System <autodist@mambasoft.it> 5.7.11-1mamba
- automatic version update by autodist

* Mon Jul 27 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 5.7.10-1mamba
- update to 5.7.10

* Thu Jul 23 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 5.4.53-1mamba
- update to 5.4.53
- fix kernel headers by installing Kconfig files; reworked to only install needed files; strip modules

* Sat Jul 11 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 5.4.51-1mamba
- update to 5.4.51

* Wed Apr 08 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 5.4.31-1mamba
- update to 5.4.31

* Sun Jan 26 2020 Automatic Build System <autodist@mambasoft.it> 5.4.15-1mamba
- automatic version update by autodist

* Thu Jan 23 2020 Automatic Build System <autodist@mambasoft.it> 5.4.14-1mamba
- automatic version update by autodist

* Sat Jan 18 2020 Automatic Build System <autodist@mambasoft.it> 5.4.13-1mamba
- automatic version update by autodist

* Sat Dec 14 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 5.4.3-1mamba
- update to 5.4.3

* Sun Jul 14 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 5.2.1-1mamba
- update to 5.2.1

* Sat Jul 06 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.19.57-1mamba
- update to 4.19.57

* Sat Jan 19 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.94-1mamba
- update to 4.14.94

* Fri Aug 03 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.60-1mamba
- update to 4.14.60

* Fri Jul 27 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.58-1mamba
- update to 4.14.58

* Sat Mar 31 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.31-1mamba
- update to 4.14.31
- mamba, mamba-64GB: unset CONFIG_GCC_PLUGIN_RANDSTRUCT and CONFIG_OF_UNITTEST

* Wed Mar 21 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.29-1mamba
- update to 4.14.29

* Thu Jan 18 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.14-1mamba
- update to 4.14.14

* Sat Jan 13 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.13-2mamba
- headers: install tools/objtool/objtool required for kbuild system (fixes virtualbox modules build)

* Wed Jan 10 2018 Automatic Build System <autodist@mambasoft.it> 4.14.13-1mamba
- automatic version update by autodist

* Tue Dec 19 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.7-1mamba
- update to 4.14.7

* Tue Dec 12 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.5-1mamba
- update to 4.14.5

* Mon Dec 04 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.3-1mamba
- update to 4.14.3

* Wed Nov 22 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.14.1-1mamba
- update to 4.14.1

* Thu Nov 09 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.13.12-1mamba
- update to 4.13.12

* Thu Nov 09 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9.61-1mamba
- update to 4.9.61
- remove obsoletes for previous (running) kernel to work with yum
- obsolete kernels < 4.4

* Sun Sep 03 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9.47-1mamba
- update to 4.9.47

* Thu Aug 17 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9.43-1mamba
- update to 4.9.43

* Tue May 30 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9.30-1mamba
- update to 4.9.30

* Wed Dec 21 2016 Automatic Build System <autodist@mambasoft.it> 4.8.13-1mamba
- automatic version update by autodist

* Sat Oct 08 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8.1-1mamba
- update to 4.8.1

* Fri Jul 29 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.6.5-1mamba
- update to 4.6.5

* Sun Jul 24 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.6.4-1mamba
- update to 4.6.4

* Thu Jul 21 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.4.15-1mamba
- update to 4.4.15

* Wed May 04 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.4.8-1mamba
- update to 4.4.8

* Tue May 03 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.23-1mamba
- update to 4.1.23

* Sat Mar 05 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.18-1mamba
- update to 4.1.18

* Tue Feb 16 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.17-2mamba
- fix obsolete for previous version to replace

* Fri Feb 12 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.17-1mamba
- update to 4.1.17

* Thu Jan 07 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.15-1mamba
- update to 4.1.15

* Thu Dec 10 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.14-1mamba
- update to 4.1.14

* Fri Sep 25 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-4mamba
- unset CONFIG_COMPAT_VDSO to  fix chromium crashes on x86

* Sun Sep 20 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-3mamba
- fix obsoletes for autoupdate

* Sat Sep 19 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-2mamba
- set CONFIG_DEVPTS_MULTIPLE_INSTANCES=y to fix recent problems with systemd-logind

* Fri Sep 04 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-1mamba
- update to 3.18.21
- posttrans: delete our old orphan initramfs from /boot

* Mon Aug 17 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.20-1mamba
- update to 3.18.20

* Thu May 21 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.14-1mamba
- update to 3.18.14
- set CONFIG_PID_NS=y

* Wed Apr 15 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.11-1mamba
- update to 3.18.11

* Thu Mar 26 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.10-1mamba
- update to 3.18.10

* Sun Feb 22 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.7-1mamba
- update to 3.18.7

* Thu Jan 29 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.30-1mamba
- update to 3.14.30

* Sat Dec 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.27-1mamba
- update to 3.14.27

* Tue Dec 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.26-1mamba
- update to 3.14.26

* Sat Nov 22 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.25-1mamba
- update to 3.14.25

* Thu Nov 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.24-2mamba
- restore SUBLEVEL in version to work better with dkms, but prepare to some bugfixing elsewhere

* Thu Nov 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.24-1mamba
- update to 3.14.24

* Fri Oct 31 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.23-1mamba
- update to 3.14.23

* Sat Oct 04 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.19-1mamba
- update to 3.14.19

* Tue Jul 08 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.11-1mamba
- update to 3.14.11

* Thu Jul 03 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.10-1mamba
- update to 3.14.10

* Sat Jun 07 2014 Automatic Build System <autodist@mambasoft.it> 3.14.5-1mamba
- automatic version update by autodist

* Sun May 18 2014 Automatic Build System <autodist@mambasoft.it> 3.14.4-1mamba
- automatic version update by autodist

* Wed May 07 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.3-1mamba
- update to 3.14.3

* Sat May 03 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.2-1mamba
- update to 3.14.2

* Thu Mar 27 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.15-1mamba
- update to 3.12.15

* Sat Mar 01 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.13-1mamba
- update to 3.12.13

* Fri Jan 17 2014 Automatic Build System <autodist@mambasoft.it> 3.12.8-1mamba
- automatic version update by autodist

* Sun Jan 12 2014 Automatic Build System <autodist@mambasoft.it> 3.12.7-1mamba
- automatic version update by autodist

* Mon Dec 23 2013 Automatic Build System <autodist@mambasoft.it> 3.12.6-1mamba
- automatic version update by autodist

* Sun Dec 15 2013 Automatic Build System <autodist@mambasoft.it> 3.12.5-1mamba
- automatic version update by autodist

* Mon Dec 09 2013 Automatic Build System <autodist@mambasoft.it> 3.12.4-1mamba
- automatic version update by autodist

* Sat Dec 07 2013 Automatic Build System <autodist@mambasoft.it> 3.12.3-1mamba
- automatic version update by autodist

* Sat Nov 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.2-1mamba
- update to 3.12.2

* Wed Oct 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.17-1mamba
- update to 3.10.17

* Sun Sep 15 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.12-1mamba
- update to 3.10.12

* Wed Sep 04 2013 Automatic Build System <autodist@mambasoft.it> 3.10.10-1mamba
- update to 3.10.10

* Thu Aug 22 2013 Automatic Build System <autodist@mambasoft.it> 3.10.9-1mamba
- automatic version update by autodist

* Fri Aug 16 2013 Automatic Build System <autodist@mambasoft.it> 3.10.7-1mamba
- automatic version update by autodist

* Thu Aug 08 2013 Automatic Build System <autodist@mambasoft.it> 3.10.5-1mamba
- automatic version update by autodist

* Thu Aug 01 2013 Automatic Build System <autodist@mambasoft.it> 3.10.4-1mamba
- automatic version update by autodist

* Fri Jul 26 2013 Automatic Build System <autodist@mambasoft.it> 3.10.3-1mamba
- automatic version update by autodist

* Mon Jul 22 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.2-1mamba
- update to 3.10.2

* Tue Jul 16 2013 Automatic Build System <autodist@mambasoft.it> 3.10.1-1mamba
- automatic version update by autodist

* Mon Jul 01 2013 Automatic Build System <autodist@mambasoft.it> 3.10-1mamba
- update to 3.10
- source edit: add missing symlink include/uapi/asm required by nvidia

* Wed May 08 2013 Automatic Build System <autodist@mambasoft.it> 3.8.12-1mamba
- update to 3.8.12

* Sun Apr 07 2013 Automatic Build System <autodist@mambasoft.it> 3.8.6-1mamba
- automatic version update by autodist

* Fri Mar 29 2013 Automatic Build System <autodist@mambasoft.it> 3.8.5-1mamba
- automatic version update by autodist

* Thu Mar 21 2013 Automatic Build System <autodist@mambasoft.it> 3.8.4-1mamba
- automatic version update by autodist

* Sun Mar 17 2013 Automatic Build System <autodist@mambasoft.it> 3.8.3-1mamba
- automatic version update by autodist

* Mon Feb 18 2013 Automatic Build System <autodist@mambasoft.it> 3.7.9-1mamba
- automatic version update by autodist

* Sat Feb 16 2013 Automatic Build System <autodist@mambasoft.it> 3.7.8-1mamba
- automatic version update by autodist

* Fri Feb 15 2013 Automatic Build System <autodist@mambasoft.it> 3.7.7-1mamba
- automatic version update by autodist

* Tue Feb 05 2013 Automatic Build System <autodist@mambasoft.it> 3.7.6-1mamba
- automatic version update by autodist

* Wed Jan 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.7.5-2mamba
- fixed wrong requirements for kernelwireless and kernelsound missing -%{kernel_ver} suffix

* Mon Jan 28 2013 Automatic Build System <autodist@mambasoft.it> 3.7.5-1mamba
- automatic version update by autodist

* Thu Jan 24 2013 Automatic Build System <autodist@mambasoft.it> 3.7.4-1mamba
- automatic version update by autodist

* Sat Jan 19 2013 Automatic Build System <autodist@mambasoft.it> 3.7.3-1mamba
- automatic version update by autodist

* Tue Jan 15 2013 Automatic Build System <autodist@mambasoft.it> 3.7.2-1mamba
- automatic version update by autodist

* Sat Dec 22 2012 Automatic Build System <autodist@mambasoft.it> 3.7.1-1mamba
- update to 3.7.1

* Sat Dec 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.11-2mamba
- added a patch to libata to restore disable acpi functionality; might fix resume problem seen on Sony Vaio VGN

* Fri Dec 21 2012 Automatic Build System <autodist@mambasoft.it> 3.6.11-1mamba
- update to 3.6.11

* Mon Dec 17 2012 Automatic Build System <autodist@mambasoft.it> 3.6.10-1mamba
- automatic version update by autodist

* Fri Dec 07 2012 Automatic Build System <autodist@mambasoft.it> 3.6.9-1mamba
- automatic version update by autodist

* Sat Dec 01 2012 Automatic Build System <autodist@mambasoft.it> 3.6.8-1mamba
- automatic version update by autodist

* Mon Nov 19 2012 Automatic Build System <autodist@mambasoft.it> 3.6.7-1mamba
- automatic version update by autodist

* Fri Nov 09 2012 Automatic Build System <autodist@mambasoft.it> 3.6.6-1mamba
- automatic version update by autodist

* Fri Nov 02 2012 Automatic Build System <autodist@mambasoft.it> 3.6.5-1mamba
- automatic version update by autodist

* Sun Oct 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.4-1mamba
- update to 3.6.4

* Mon Oct 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.3-1mamba
- update to 3.6.3

* Sat Oct 13 2012 Automatic Build System <autodist@mambasoft.it> 3.6.2-1mamba
- automatic version update by autodist
- new target: kernel-64GB-rt with RT patch by Ingo Molnar

* Sat Oct 13 2012 Automatic Build System <autodist@mambasoft.it> 3.6.1-1mamba
- update to 3.6.1

* Wed Oct 10 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.13-1mamba
- update to 3.4.13

* Sat Oct 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.12-1mamba
- update to 3.4.12

* Tue Sep 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.11-1mamba
- update to 3.4.11
- source edit (next release): set CONFIG_TMPFS_POSIX_ACL=y as required by udisks2

* Wed Sep 05 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.10-1mamba
- update to 3.4.10

* Sat Aug 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.9-1mamba
- update to 3.4.9
- apply overlayfs patches (v13) from http://git.kernel.org/?p=linux/kernel/git/mszeredi/vfs.git
- (source edit next-release) added patch to option module to support Huawey E352 on boot

* Tue Aug 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.8-1mamba
- update to 3.4.8

* Wed Aug 01 2012 Automatic Build System <autodist@mambasoft.it> 3.4.7-1mamba
- automatic version update by autodist
- (source edit) prepare setting CONFIG_RTC_DRV_CMOS=y in all configs for next build

* Fri Jul 20 2012 Automatic Build System <autodist@mambasoft.it> 3.4.6-1mamba
- automatic version update by autodist

* Tue Jul 17 2012 Automatic Build System <autodist@mambasoft.it> 3.4.5-1mamba
- automatic version update by autodist

* Thu Jun 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.4-1mamba
- update to 3.4.4

* Wed Jun 20 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.21-1mamba
- update to 3.2.21

* Wed Jun 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.19-1mamba
- update to 3.2.19

* Sat Jun 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.18-1mamba
- update to 3.2.18

* Thu May 17 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.17-1mamba
- update to 3.2.17

* Thu May 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.16-1mamba
- update to 3.2.16
- ipw2200 patch from http://marc.info/?l=linux-wireless&m=133486517923084&w=2

* Sat Apr 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.15-1mamba
- update to 3.2.15

* Fri Apr 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.14-2mamba
- fix minor release patch application: it was not applied any longer since format is .xz

* Wed Apr 04 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.14-1mamba
- update to 3.2.14

* Mon Mar 26 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.13-1mamba
- update to 3.2.13

* Wed Mar 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.11-1mamba
- update to 3.2.11

* Fri Mar 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.9-1mamba
- update to 3.2.9

* Fri Mar 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.8-1mamba
- update to 3.2.8

* Tue Feb 21 2012 Automatic Build System <autodist@mambasoft.it> 3.2.7-1mamba
- automatic version update by autodist

* Wed Feb 15 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.6-1mamba
- update to 3.2.6
- configs: disabled deprecated CONFIG_ACPI_PROCFS_POWER
- run grub-set-default 0 to enable reboot from latest release

* Sat Feb 11 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.5-1mamba
- update to 3.2.5

* Mon Jan 30 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.10-2mamba
- added patches to fix unresponsiveness and crash due to mm hugepage defrag (https://bugzilla.redhat.com/show_bug.cgi?id=735946)

* Wed Jan 25 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.10-1mamba
- update to 3.1.10

* Mon Nov 14 2011 Automatic Build System <autodist@mambasoft.it> 3.1.1-1mamba
- update to 3.1.1

* Thu Nov 03 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.8-2mamba
- added a patch which fixes firmware task freezing during suspend (seen with mtp-probe and ift-load on macbook pro)

* Mon Oct 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.8-1mamba
- update to 3.0.8
- config: enabled CONFIG_PM_TRACE_RTC for resume after suspend debugging (i586 and i586-64GB)

* Sun Oct 23 2011 Automatic Build System <autodist@mambasoft.it> 3.0.7-1mamba
- automatic version update by autodist

* Fri Oct 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-4mamba
- added patches for new ALPS touchpad protocols and ids support (https://bugs.gentoo.org/show_bug.cgi?id=318567)
- config: set psmouse as a module

* Wed Sep 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-3mamba
- config: enabled CONFIG_TIMER_STATS as required by gnome-power-manager
- kernel-wireless: require crda

* Fri Sep 16 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-2mamba
- fix install of modules.builtin, modules.builtin.bin and modules.order in /lib/modules kernel folder

* Sat Sep 03 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-1mamba
- update to 3.0.4

* Tue Aug 23 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-3mamba
- enable CONFIG_EXT4_FS_SECURITY and CONFIG_SQUASHFS_XATTR

* Sun Aug 21 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-2mamba
- require linux-firmware; moved insternally provided firmware files to subpackage -firmware

* Fri Aug 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-1mamba
- update to 2.6.39.4

* Sat Jul 09 2011 Automatic Build System <autodist@mambasoft.it> 2.6.39.3-1mamba
- automatic update by autodist

* Thu Jul 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.2-1mamba
- update to 2.6.39.2
- reiser4 patch temporary disabled because it is unavailable upstream

* Wed Jul 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.8-1mamba
- update to 2.6.38.8

* Tue May 10 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.6-1mamba
- automatic update by autodist

* Mon May 09 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.5-2mamba
- unionfs: patch updated to 2.5.9.1_for_2.6.38.4
- fix old provide and obsolete to prevent kernel-mamba-64GB to remove kernel-mamba

* Tue May 03 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.5-1mamba
- automatic update by autodist

* Wed Apr 27 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.4-1mamba
- automatic update by autodist

* Tue Apr 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.3-1mamba
- update to 2.6.38.3

* Mon Mar 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.6-1mamba
- update to 2.6.37.6

* Sat Mar 26 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.5-1mamba
- update to 2.6.37.5

* Tue Mar 15 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.4-1mamba
- automatic update by autodist

* Tue Mar 08 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.3-1mamba
- automatic update by autodist

* Mon Feb 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.2-1mamba
- update to 2.6.37.2
- addded pacthes: vga_dont_ask, unionfs-2.5.7-evict_inode_end_writeback
- restore delay_use patch to fix usb live boot

* Sat Feb 19 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.1-1mamba
- automatic update by autodist
- added patch to fix flickering problems seen with radeon kms driver

* Sun Feb 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37-1mamba
- update to 2.6.37

* Thu Jan 20 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.10-2mamba
- add patch:drm-radeon-r600-cs-checker-fixes to fix 'r600_cs_track_validate_cb:203 cb pitch (64) invalid'

* Thu Dec 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.10-1mamba
- update to 2.6.35.10

* Thu Dec 16 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.9-1mamba
- update to 2.6.35.9

* Tue Nov 09 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-6mamba
- replace depmod -A with depmod -a to ensure module deps are updated

* Wed Sep 29 2010 Davide Madrisan <davide.madrisan@gmail.com> 2.6.33.7-5mamba
- added patch to prevent tpm driver to hang for a couple of minutes on some hardware

* Sat Sep 18 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-4mamba
- fixed support for VESA framebuffer support by reenabling CONFIG_FB_VESA=y CONFIG_FB_EFI=y
- added patch to support CTI USB-485-Mini and USB-Nano-485 devices
- create failsafe initramfs using dracut in main package (removed -failsafe package)

* Sun Sep 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-3mamba
- remove deprecated ATA/ATAPI support in favour of PATA/SATA subsystem
- ppc: some config sync with i586

* Sun Sep 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-2mamba
- removed fbsplash patch; switch to use mkinitrd from dracut with plymouth

* Thu Aug 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-1mamba
- update to 2.6.33.7
- added failsafe package with universal initramfs
- fixed mkinitramfs version prerequirement
- moved initramfs creation to posttrans script

* Sun Jul 25 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.6-2mamba
- enabled build of staging drivers (builds nouveau and vmwgfx drm drivers)

* Fri Jul 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.6-1mamba
- update to 2.6.33.6
- backport from 2.6.31.13-1mamba:
  exclude scsi/scsi.h from sanitized headers with __u8 type problem, glibc will more properly install its own

* Fri Jun 18 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.5-1mamba
- update to 2.6.33.5

* Thu May 13 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.4-1mamba
- automatic update to 2.6.33.4 by autodist

* Mon Apr 26 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.3-1mamba
- automatic update to 2.6.33.3 by autodist

* Wed Apr 07 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.2-1mamba
- automatic update to 2.6.33.2 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.1-1mamba
- update to 2.6.33.1

* Sun Mar 14 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33-1mamba
- automatic update to 2.6.33 by autodist

* Thu Mar 11 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.12-2mamba
- resync patches with kernel 2.6.30.10:
  * added patches for SquashFS with LZMA support
  * 8139too: added patch to keep supporting previous supported chip instead of forcing use of 8139cp

* Fri Mar 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.12-1mamba
- update to 2.6.31.12

* Sat Jan 16 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.11-1mamba
- update to 2.6.31.11

* Tue Nov 10 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.6-1mamba
- automatic update to 2.6.31.6 by autodist

* Fri Oct 23 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.5-1mamba
- automatic update to 2.6.31.5 by autodist

* Tue Oct 13 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.4-1mamba
- automatic update to 2.6.31.4 by autodist

* Sun Sep 27 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.1-1mamba
- automatic update to 2.6.31.1 by autodist

* Fri Sep 11 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31-1mamba
- update to 2.6.31

* Tue Sep 08 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.5-2mamba
- disabled CONFIG_USB_OHCI_HCD_SSB to prevent ssb.ko crash on some machines with b43 chipset

* Mon Aug 17 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.5-1mamba
- automatic update to 2.6.30.5 by autodist

* Sun Aug 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.4-2mamba
- added wmi patch: Fix kernel panic when stack protection enabled (http://patchwork.kernel.org/patch/32222/)

* Fri Jul 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.4-1mamba
- update to 2.6.30.4

* Wed Jul 29 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.3-2mamba
- added patch that exports symbol flush_tlb_page required by fglrx

* Sat Jul 25 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.3-1mamba
- automatic update to 2.6.30.3 by autodist

* Mon Jul 20 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.2-1mamba
- automatic update to 2.6.30.2 by autodist

* Mon Jul 06 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.1-1mamba
- automatic update to 2.6.30.1 by autodist

* Sat Jun 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.29.5-1mamba
- update to 2.6.29.5

* Tue Jun 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-3mamba
- added unionfs patch

* Wed May 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-2mamba
- added reiser4 support with external patch

* Tue May 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-1mamba
- update to 2.6.28.10
- added MSG_PEEK_race_msg patch to remove an incorrect debug message with fetchmail
  (see www.spinics.net/lists/ntdev/msg96700.html)

* Mon Apr 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.9-2mamba
- fixed application of patchlevel release patch

* Sat Apr 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.9-1mamba
- update to 2.6.28.9

* Thu Apr 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-3mamba
- added kernel-headers-sanitised package for glibc

* Tue Mar 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-2mamba
- IDE support configuration changed to fix boot issues

* Tue Mar 17 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-1mamba
- automatic update to 2.6.28.8 by autodist

* Fri Mar 06 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-4mamba
- disable CONFIG_SYSFS_DEPRECATED* for current udev/HAL to work correctly

* Mon Mar 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-3mamba
- move new wireless drivers provides by backports to the wireless subpackage

* Mon Feb 23 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-2mamba
- disabled CONFIG_SECURITY_ROOTPLUG to fix boot

* Sat Feb 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-1mamba
- update to 2.6.28.7

* Fri Feb 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.6-1mamba
- update to 2.6.28.6

* Thu Feb 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-6mamba
- enable CONFIG_SYSFS_DEPRECATED_V2 to fix pmount behaviour

* Thu Feb 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-5mamba
- added ACPI GPE storm patch (ReHat bug 11089 http://bugzilla.kernel.org/show_bug.cgi?id=11089)

* Sat Jan 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-4mamba
- added requirement for kernelwireless
- run depmod upon kernel-wireless and kernel-sound packages installation

* Mon Jan 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-3mamba
- kernel-sound: added virtual provide kernelsound
- kernel-wireless: added virtual provide kernelwireless

* Thu Dec 18 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-2mamba
- rebuilt with snd as a module
- added sound subpackage

* Tue Dec 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-1mamba
- update to 2.6.26.8
- unset CONFIG_X86_PAT to prevent video card problems on some systems
- move new wireless drivers to dedicated subpackage
- move MARKER touch from source to headers subpackage

* Mon Sep 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.5-2mamba
- atl1: add patch that disables TSO by default to avoid sendfile() data curruption
- config: enabled time information on printk's

* Sun Sep 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.5-1mamba
- update to 2.6.26.5

* Wed Jul 30 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.4mamba
- repackage to fix wrong kernel with old wireless drivers in main package

* Fri Jul 18 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.3mamba
- enabled in it CONFIG_NETDEVICES_MULTIQUEUE for wireless drivers compatibility
- wireless modules provided by wireless-compat (kernel-extramodules) excluded 

* Fri Jun 27 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.2mamba
- remove usbstorage disable delay patch
- mactel patches updated

* Wed May 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.1mamba
- update to 2.6.24.7
- excluded drivers usbnet, cdc_ether, rndis_host in favour of usb-rndis-lite 
  drivers in kernel-extramodules

* Mon Mar 24 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-5.1mamba
- update to 2.6.24.5
- added (experimental) kernel-headers subpackage

* Mon Mar 24 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-4.1mamba
- update to 2.6.24.4

* Thu Mar 20 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.4mamba
- removed files in /etc/grub2
- snd_hda_intel: added PCI_QUIRK patch for Acer Aspire 7720G

* Sat Mar 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.3mamba
- build cpu frequency governors as modules; leave userspace as the default

* Fri Mar 07 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.2mamba
- disabled XEN support because it is not supported by NVIDIA drivers

* Fri Mar 07 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.1mamba
- update to 2.6.24.3
- realtime_lsm: dropped support (use /etc/security/limits.conf)

* Mon Feb 11 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-2.1mamba
- update to 2.6.24.2

* Sun Feb 10 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-1.1mamba
- update to 2.6.24.1

* Fri Feb 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-0.2mamba
- fixed configuration of fbcondecorpatch (disable FB_TILEBLITTING)
- remove code for suspend2 (resume=)

* Tue Jan 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-0.1mamba
- update to 2.6.24
- removed uvesafb patch (included upstream)
- fbsplash patch upgraded (now it is called fbcondecor)

* Tue Jan 15 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-14.1mamba
- update to 2.6.23.14
- squashfs patch: update to 3.3

* Sat Jan 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-13.1mamba
- update to 2.6.23.13
- grub2: launch update-grub
- remove no longer (and never since) used /etc/grub2 contents

* Tue Jan 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.4mamba
- set USERSPACE cpu frequency governor as the default (replacing PERFORMANCE)

* Tue Dec 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.3mamba
- added patch to support Zepto notebooks PCIid's

* Mon Dec 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.2mamba
- pass uvesafb instead of vesafb as kernel parameter
- config: removed FB_VESA 
- added requirement for v86d

* Fri Dec 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.1mamba
- update to 2.6.23.12
- backport of snd_hda_intel from alsa 1.0.15 for Zepto notebooks

* Fri Oct 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-1.1mamba
- update to 2.6.23.1
- vesafb_tng patch replaced by uvesafb

* Fri Oct 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-10.1mamba
- update to 2.6.22.10

* Tue Sep 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-8.1mamba
- update to 2.6.22.8

* Sat Sep 22 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-7.1mamba
- update to 2.6.22.7
- CONFIG_HZ set back to 1000 (or audio applications like Rosegarden complain)

* Wed Sep 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-6.2mamba
- disable deprecated option X86_SPEEDSTEP_CENTRINO_ACPI
- ppc: new target build; updated configuration

* Wed Sep 05 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-6.1mamba
- update to 2.6.22.6

* Sun Aug 26 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-5.1mamba
- update to 2.6.22.5

* Thu Aug 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-3.1mamba
- update to 2.6.22.3
- kernel-source: declare config/MARKER as ghost file to allow better cleanup on upgrade

* Fri Aug 10 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-2.1mamba
- update to 2.6.22.2

* Wed Jul 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-1.2mamba
- mactel patch updated
- CONFIG_HZ set to 300 (was 1000)

* Wed Jul 11 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-1.1mamba
- update to 2.6.22.1
- dropped support code for std,old smp,smppreempt and preempt kernels

* Wed Jun 13 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-5.1mamba
- update to 2.6.21.5
- dropped VT3351-disable_msi patch merged upstream

* Mon Jun 11 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-4.3mamba
- fix posttrans script for grub-update execution

* Fri Jun 08 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-4.1mamba
- update to 2.6.21.4
- added support for grub2

* Mon Jun 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-3.2mamba
- add patch that disables NMI on Asus M2V boards (chipset vt3351)
- port of snd_hda_intel driver from alsa 1.0.14
- added patch for kvm (fixes exception #13 qemu error)

* Fri May 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-3.1mamba
- update to 2.6.21.3

* Thu May 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-2.1mamba
- update to 2.6.21.2

* Sat Apr 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-1.1mamba
- update to 2.6.21.1

* Thu Apr 26 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-0.1mamba
- update to 2.6.21

* Tue Apr 17 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-7.1mamba
- update to 2.6.20.7

* Sat Apr 07 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-6.1mamba
- update to 2.6.20.6

* Fri Apr 06 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-5.1mamba
- update to 2.6.20.5

* Sat Mar 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-4.1qilnx
- update to 2.6.20.4

* Wed Mar 14 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-3.1qilnx
- update to 2.6.20.3

* Mon Mar 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-2.1qilnx
- update to 2.6.20.2
- readded suspend2 patch and updated to 2.2.9.9
- fbsplash: update to 0.9.2-r5-2.6.20-rc6

* Sun Mar 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-1.2qilnx
- fix wrong symlink from /lib/modules to sources

* Wed Feb 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-1.1qilnx
- update to 2.6.20.1

* Fri Feb 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.3qilnx
- remove suspend2 patch

* Thu Feb 15 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.2qilnx
- remove need for theme mamba, will use default instead

* Mon Feb 05 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.1qilnx
- update to 2.6.20

* Tue Jan 02 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.19-1.1qilnx
- update to 2.6.19.1
- snd_hda_intel: fix a NULL pointer bug
- post script: fix resume2 configuration bug with two or more swap partitions

* Thu Nov 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.19-0.1qilnx
- update to 2.6.19

* Mon Nov 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-3.1qilnx
- update to 2.6.18.3

* Wed Nov 15 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.3qilnx
- fix and really apply new imac patch

* Tue Nov 14 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.2qilnx
- remove realtime preempt patch for mamba target

* Mon Nov 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.1qilnx
- update to 2.6.18.2
- set CONSOLE=tty1 for bootsplash
- rt patch: update to rt7
- imac patches updates to current mactel-linux svn + sigmatel patch for microphone

* Fri Oct 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-1.2qilnx
- rt patch: update to rt6
- rename packages from kernel26 to kernel

* Sat Oct 14 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-1.1qilnx
- new build for 2.6.18.1 patch release

* Sun Oct 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.5qilnx
- add suspend2 patch
- add realtime lsm patch (updated to 0.8.7 and moved from kernel26-extramodules)
- enable EEPRO100 ethernet driver module
- enable as built-in the LZF compression algohorithm needed by suspend2

* Wed Oct 04 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.4qilnx
- disable bootsplash fadein
- set PERFORMANCE CPUFREQ governor (for test pourposes against USERSPACE)

* Sat Sep 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.3qilnx
- rt5 patch applied
- build usbhid as a module because appletouch module has to be loaded before

* Thu Sep 28 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.2qilnx
- dropped ck preemptible kernel patch in favour of Ingo Molnar's realtime patch

* Thu Sep 21 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.1qilnx
- new kernel release build
- squashfs update to 3.1-r2

* Sun Jul 16 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-6.1qilnx
- new kernel subrelease build

* Tue Jul 11 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-4.2qilnx
- added applesmc patch for MacBook motion/light sensors and keyboard backlight

* Fri Jul 07 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-4.1qilnx
- kernel update to 2.6.17.4
- added sigmatel patch to make audio work on 15" MacBook Pro's
- removed imacfb
- added radeonfb and matroxfb builtin

* Wed Jul 05 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-3.1qilnx
- kernel update to 2.6.17.3
- add support for initramfs

* Fri Jun 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-2.1qilnx
- kernel update to 2.6.17.2
- mamba: loop device modules built-in
- mamba: console framebuffer device build as module
- removed bootsplash patch
- added fbsplash patch
- added vesafb-tng patch

* Tue Jun 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-1.1qilnx
- kernel update to 2.6.17.1
- new kernel target "mamba"

* Tue Jun 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-0.1qilnx
- kernel update to 2.6.17
- added cleane headers patch from -mm

* Wed Jun 07 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.16-20.1qilnx
- kernel update to 2.6.16.20

* Sat May 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-16.1qilnx
- kernel update to 2.6.16.16
- ck patch update to 2.6.16-ck10
- set CONFIG_VMSPLIT_3G again because of problems with wine and valgrind
- kernel smppreempt: set PENTIUMIII as target processor

* Mon May 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-14.1qilnx
- kernel patch release update to 2.6.16.14
- ck patches update to 2.6.16-ck9 

* Sun Apr 23 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-9.2qilnx
- removed %posttrans script, moved to %post ($1 variable is not handled)

* Fri Apr 21 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-9.1qilnx
- add rtc in kernel monolith
- set CONFIG_VMSPLIT_2G for iMacs
- added imacfb
- set PCI_MSI=y on all i586 configs
- set CONFIG_BLK_DEV_SD=y, CONFIG_SCSI_SATA_AHCI=y on all i586 configs

* Mon Apr 17 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-5.2qilnx
- add support for EFI boot and partitions

* Thu Apr 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-5.1qilnx
- new subrelease build
- Intel Mac patch from Mac-Tel added for Intel Macs
- add support for new smppreempt target

* Mon Mar 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-0.1qilnx
- new version build
- create symlinks /dev/loop[0-2] if missing (for update from QiLinux 1.2)
- execute lilo-config --killdevfs (for update from QiLinux 1.2)

* Wed Feb 22 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-4.2qilnx
- ck preempt-realtime patch update to ck4
- ACPI sleep states support enabled

* Fri Feb 10 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-4.1qilnx
- new subrelease build
- remove lilo prereq

* Wed Feb 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-3.1qilnx
- new subrelease build
- added initial grub support

* Wed Jan 11 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-0.1qilnx
- new kernel version build

* Mon Dec 19 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-4.1qilnx
- new subrelease build
- added distcc build support

* Mon Dec 12 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-3.2qilnx
- preempt: remove ck's prefetch of swap pages
- preempt: disable AS and deadline I/O scheduling

* Fri Dec 02 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-3.1qilnx
- new rt patch rt21
- new subrelease build
- add Con Kolivas patch to preempt and rt targets

* Fri Nov 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-2.2qilnx
- new single target specfile
- rename kernel26 to kernel
- change subpkgs names from kernel-<extra>-<target> to kernel-<target>-<extra>

* Wed Nov 16 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-2.1qilnx
- new kernel version build

* Sat Nov 12 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.3qilnx
- rt_preempt: fix missing export for tsc_c3_compensate symbol

* Fri Nov 11 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.2qilnx
- preempt: disabled realtime preemption
- preempt: disabled CONFIG_SPINLOCK_BKL

* Sat Nov 05 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.1qilnx
- new subrelease build
- add realtime-preempt patch to preempt target

* Thu Oct 06 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-3.1qilnx
- new version build

* Tue Sep 20 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-2.1qilnx
- new version build
- ppc target fixes in scripts

* Sat Sep 10 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-1.1qilnx
- new version build

* Wed Aug 10 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-4.1qilnx
- new subrelease build

* Mon Jul 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-3.1qilnx
- new subrelease build

* Thu Jun 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-2.1qilnx
- new subrelease build
- disabled devfs mount on boot (requires new mkinitrd)

* Mon Jun 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-1.1qilnx
- new version build

* Wed Jun 22 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.12-1qilnx
- supermount patch disabled (see http://bhhdoa.org.au/pipermail/ck/2005-May/003462.html)

* Sun May 29 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.11-1qilnx
- new version build
- built kernels processor type changed to Pentium-Pro (686)
- added patchlevel support for modules (installed to 2.6.11 modules dir)

* Sun May 15 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.9-1qilnx
- new version build
- fixed lilo updates problem (added release to files)
- also fixes CAN-2005-1263 security vulnerability

* Sat Apr 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.8-1qilnx
- new versiion build
- lilo-config: add --keep-default option to %pre scripts

* Wed Apr 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-4qilnx
- add patch to remove 8139cp hotplugging for Realtek 8139 cards and use 8139too instead

* Thu Mar 31 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.6-3qilnx
- changes in %%pre and %%postun scriptlets required by the new lilo-config tool

* Wed Mar 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-2qilnx
- changed lilo-config and mkinitrd execution order for bootsplash configuration

* Tue Mar 29 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-1qilnx
- new version build (also fix security issues: CAN-2005-[0400,0794,0794,0815])
- added specfile support for pl releases patches
- removed rpm release from lilo.d configuration file names

* Mon Mar 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.5-1qilnx
- new version build
- scriptlets modified (kernel26 requires the new lilo-config script)
- set vga=0x314 in the lilo kernel blocks

* Thu Mar 17 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.4-1qilnx
- new version build

* Tue Mar 08 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.1-1qilnx
- new version build
- preempt kernel: added supermount-ng patch 2.08

* Mon Feb 28 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-6qilnx
- rebuilt with 4GB high memory support

* Sun Feb 20 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-5qilnx
- rebuilt with security capabilities as a module and with linux SE enabled

* Tue Jan 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-4qilnx
- rebuild with SCSI sg (generic) support as a module and not built-in

* Tue Jan 11 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-3qilnx
- rebuild with ide_scsi as a module and not built-in

* Thu Dec 30 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-2qilnx
- rebuilt with gcc 3.4

* Thu Dec 30 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-1qilnx
- new version build

* Wed Dec 01 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.9-2qilnx
- rebuilt with security capabilities build-in and not as a module

* Mon Nov 08 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.9-1qilnx
- new version build

* Sun Aug 15 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.8.1-2qilnx
- fix build script because Kernel Makefile extraver is .1 and not null 
  (replace it with .1,.1smp and .1preempt)

* Sun Aug 15 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.8.1-1qilnx
- new version build
- added directory /sys (insted of it being created by mountproc initscript)
- lilo label renamed to qilinux-26<extraver>

* Wed Jul 07 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.7-3qilnx
- added "make prepare-all" needed to build the kernel26-extramodules 
  package

* Mon Jun 28 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.7-2qilnx
- rebuild without cloop module (it is now in kernel-extramodules)

* Fri Jun 18 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.7-1qilnx
- new version build
- added cloop module built-in compile

* Thu May 20 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.6-3qilnx
- moved code from %post scriptlets to /sbin/lilo-config (lilo package)

* Tue May 18 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.6-2qilnx
- rebuild for standard, smp and preempt targets

* Mon May 10 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.6-1qilnx
- rebuilt with kernel-2.6.6

* Mon Apr 05 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.5-1qilnx
- rebuilt with kernel-2.6.5

* Thu Mar 25 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.4-2qilnx
- added more kernel modules
- fixed post script

* Fri Mar 12 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.4-1qilnx
- rebuilt with version 2.6.4

* Sat Jan 10 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.1-1qilnx
- rebuilt with version 2.6.1

* Thu Dec 18 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0-1qilnx
- rebuilt with the new born 2.6.0 version :)

* Sat Nov 22 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0test9-1qilnx
- fixed some kernel boot problems

* Sat Oct 25 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0test8-1qilnx
- first building of a kernel from branch 2.6.x
